==> zio-aws-apigatewayv2_3-5.17.130.3-sources.jar: zio/aws/apigatewayv2/model/GetModelRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class GetModelRequest(apiId: __string, modelId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetModelRequest = {
    import GetModelRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetModelRequest
      .builder()
      .apiId(__string.unwrap(apiId): java.lang.String)
      .modelId(__string.unwrap(modelId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.GetModelRequest.ReadOnly =
    zio.aws.apigatewayv2.model.GetModelRequest.wrap(buildAwsValue())
}
object GetModelRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetModelRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetModelRequest =
      zio.aws.apigatewayv2.model.GetModelRequest(apiId, modelId)
    def apiId: __string
    def modelId: __string
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getModelId: ZIO[Any, Nothing, __string] = ZIO.succeed(modelId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetModelRequest
  ) extends zio.aws.apigatewayv2.model.GetModelRequest.ReadOnly {
    override val apiId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.apiId())
    override val modelId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.modelId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetModelRequest
  ): zio.aws.apigatewayv2.model.GetModelRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-apigatewayv2_3-5.17.295.8-sources.jar: zio/aws/apigatewayv2/model/GetModelRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class GetModelRequest(apiId: __string, modelId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetModelRequest = {
    import GetModelRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetModelRequest
      .builder()
      .apiId(apiId: java.lang.String)
      .modelId(modelId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.GetModelRequest.ReadOnly =
    zio.aws.apigatewayv2.model.GetModelRequest.wrap(buildAwsValue())
}
object GetModelRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetModelRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetModelRequest =
      zio.aws.apigatewayv2.model.GetModelRequest(apiId, modelId)
    def apiId: __string
    def modelId: __string
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getModelId: ZIO[Any, Nothing, __string] = ZIO.succeed(modelId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetModelRequest
  ) extends zio.aws.apigatewayv2.model.GetModelRequest.ReadOnly {
    override val apiId: __string = impl.apiId(): __string
    override val modelId: __string = impl.modelId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetModelRequest
  ): zio.aws.apigatewayv2.model.GetModelRequest.ReadOnly = new Wrapper(impl)
}
